@@ -1,5 +1,5 @@
-from .linear import LinearRegression
-from .measurement import MeasurementList
+from labtex.linear import LinearRegression
+from labtex.measurement import MeasurementList
 
 from typing import List, Union
 
@@ -29,9 +29,8 @@ class Document:
 }
 
 \section{Introduction}
-\subsection{Aim}
 
-\subsection{Theory}
+\section{Theory}
 
 \section{Method}
 
@@ -45,7 +44,7 @@ class Document:
 
 \section{Discussion}
 
-\section{Bibliography}
+\section*{References}
 
 \end{document}
 """
@@ -163,10 +162,8 @@ class Document:
 
         eq = LinearRegression(*data)
         filename = f"graph{self.graphnumber}"
-        eq.savefig(Document.graphfolder + filename,title,xnameandsymbol,ynameandsymbol)
-        print(f"labtex: Wrote to '{Document.graphfolder + filename}.png'.")
 
-        if(Document.graphfolder != '.'): # assuming the folder is a subfolder
+        if(Document.graphfolder != '.'): # assuming the graph folder is a subfolder
             graph = graph.replace("!filename","../" + Document.graphfolder +  filename)
         else:
             graph = graph.replace("!filename", Document.graphfolder + filename)
@@ -175,6 +172,9 @@ class Document:
 
         if (not os.path.exists(Document.graphfolder)):
             os.makedirs(Document.graphfolder)
+            
+        eq.savefig(Document.graphfolder + filename,title,xnameandsymbol,ynameandsymbol,showline,self.graphnumber)
+        print(f"labtex: Wrote to '{Document.graphfolder + filename}.png'.")
 
     def save(self,filename: str ="labdocument"):
         "Save the document to 'filename.tex'."
@@ -182,7 +182,7 @@ class Document:
         self.document = self.document.replace("!table","").replace("!graph","")
 
         if(not os.path.exists(Document.texfolder)):
-            os.makdirs(Document.texfolder)
+            os.makedirs(Document.texfolder)
 
         with open(Document.texfolder + filename + '.tex','w') as outputfile:
             outputfile.write(self.document)
