@@ -1,5 +1,5 @@
 
-from .measurement import Measurement, MeasurementList
+from labtex.measurement import Measurement, MeasurementList
 
 import matplotlib.pyplot as plt 
 
@@ -38,12 +38,14 @@ class LinearRegression:
         }
 
     def __repr__(self):
-        return f"{self.lobf['m']}{' + ' if self.lobf['c'].value > 0 else ' '}{self.lobf['c']}"
+        return f"m = {self.lobf['m']}\nc = {self.lobf['c']}"
 
-    def savefig(self,filename : str = "figure", title: str = "", xlabel : str = "", ylabel: str = ""):
+    def savefig(self,filename : str = "figure", title: str = "", xlabel : str = "", ylabel: str = "",showline : bool = True, graphnumber : int = 0):
+        plt.figure(graphnumber)
         plt.errorbar(self.x.tolist(),self.y.tolist(),yerr = self.y.uncertainty,fmt='o')
-        plt.plot(self.x.tolist(),(self.x*self.lobf["m"].value+self.lobf["c"].value).tolist())
+        if showline:
+            plt.plot(self.x.tolist(),(self.x*self.lobf["m"].value+self.lobf["c"].value).tolist())
         plt.title(title)
-        plt.xlabel(xlabel + f", ({self.x.unit})")
-        plt.ylabel(ylabel + f", ({self.y.unit})")
+        plt.xlabel(xlabel + f", (${self.x.unit}$)")
+        plt.ylabel(ylabel + f", (${self.y.unit}$)")
         plt.savefig(filename)
